@@ -1,7 +1,7 @@
 package Log::Dispatch::FileWriteRotate;
 
-our $DATE = '2015-01-26'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2021-07-21'; # DATE
+our $VERSION = '0.061'; # VERSION
 
 use 5.010001;
 use warnings;
@@ -26,9 +26,8 @@ sub _make_handle {
     my %args = @_;
 
     for (keys %args) {
-        # XXX hook_*
         delete $args{$_} unless /\A(
-                                     dir|prefix|suffix|period|size|histories|
+                                     hook_.+|dir|prefix|suffix|period|size|histories|
                                      binmode|buffer_size|lock_mode|
                                      rotate_probability
                                  )\z/x;
@@ -58,7 +57,7 @@ Log::Dispatch::FileWriteRotate - Log to files that archive/rotate themselves, w/
 
 =head1 VERSION
 
-This document describes version 0.03 of Log::Dispatch::FileWriteRotate (from Perl distribution Log-Dispatch-FileWriteRotate), released on 2015-01-26.
+This document describes version 0.061 of Log::Dispatch::FileWriteRotate (from Perl distribution Log-Dispatch-FileWriteRotate), released on 2021-07-21.
 
 =head1 SYNOPSIS
 
@@ -85,6 +84,12 @@ L<File::Write::Rotate> as backend, thus interoperates more easily with other
 modules which use File::Write::Rotate as backend, e.g.
 L<Tie::Handle::FileWriteRotate> or L<Process::Govern>.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <sharyanto@cpan.org>
+
 =head1 METHODS
 
 =head2 new(%args)
@@ -100,12 +105,6 @@ Send a message to the appropriate output. Generally this shouldn't be called
 directly but should be called through the C<log()> method (in
 LLog::Dispatch::Output>).
 
-=head1 SEE ALSO
-
-L<Log::Dispatch>
-
-L<File::Write::Rotate>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Log-Dispatch-FileWriteRotate>.
@@ -122,13 +121,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Log::Dispatch>
+
+L<File::Write::Rotate>
+
+L<Log::Dispatch::FileRotate>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2019, 2015, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
